==> dmn-drools-springboot-metrics-1.7.0.Final-sources.jar: org/kie/kogito/examples/Rules471B42E068A21F8D5BEF529A54AE3B27_HelloRuleMethods0.java <==
package org.kie.kogito.examples;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import static org.kie.kogito.examples.Rules471B42E068A21F8D5BEF529A54AE3B27.*;

public class Rules471B42E068A21F8D5BEF529A54AE3B27_HelloRuleMethods0 {

    /**
     * Rule name: helloWorld
     */
    public static org.drools.model.Rule rule_helloWorld() {
        final org.drools.model.Variable<java.lang.String> var_$s = D.declarationOf(java.lang.String.class,
                                                                                   DomainClassesMetadata471B42E068A21F8D5BEF529A54AE3B27.java_lang_String_Metadata_INSTANCE,
                                                                                   "$s",
                                                                                   D.entryPoint("strings"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.examples",
                                            "helloWorld").unit(org.kie.kogito.examples.Hello.class)
                                                         .build(D.pattern(var_$s).expr("GENERATED_B7CAA03EC808C9E791FCB5A37669D56E",
                                                                                       org.kie.kogito.examples.P72.LambdaPredicate72C5688A847B3014FA27D5614A1A380C.INSTANCE,
                                                                                       D.alphaIndexedBy(java.lang.String.class,
                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                        -1,
                                                                                                        org.kie.kogito.examples.P29.LambdaExtractor2934B2601A92547C87ADC11C141933B6.INSTANCE,
                                                                                                        "hello")),
                                                                D.on(var_strings).execute(org.kie.kogito.examples.PF9.LambdaConsequenceF9EFB357CF6EB2205514EBE11E588FA1.INSTANCE));
        return rule;
    }
}

==> dmn-drools-springboot-metrics-1.11.1.Final-sources.jar: org/kie/kogito/examples/Rules471B42E068A21F8D5BEF529A54AE3B27_HelloRuleMethods0.java <==
package org.kie.kogito.examples;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import static org.kie.kogito.examples.Rules471B42E068A21F8D5BEF529A54AE3B27.*;

public class Rules471B42E068A21F8D5BEF529A54AE3B27_HelloRuleMethods0 {

    /**
     * Rule name: helloWorld
     */
    public static org.drools.model.Rule rule_helloWorld() {
        final org.drools.model.Variable<java.lang.String> var_$s = D.declarationOf(java.lang.String.class,
                                                                                   DomainClassesMetadata471B42E068A21F8D5BEF529A54AE3B27.java_lang_String_Metadata_INSTANCE,
                                                                                   "$s",
                                                                                   D.entryPoint("strings"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.examples",
                                            "helloWorld").unit(org.kie.kogito.examples.Hello.class)
                                                         .build(D.pattern(var_$s).expr("GENERATED_B7CAA03EC808C9E791FCB5A37669D56E",
                                                                                       org.kie.kogito.examples.P3B.LambdaPredicate3B467EBC89E080035352192545DDE5E1.INSTANCE,
                                                                                       D.alphaIndexedBy(java.lang.String.class,
                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                        -1,
                                                                                                        org.kie.kogito.examples.P29.LambdaExtractor2934B2601A92547C87ADC11C141933B6.INSTANCE,
                                                                                                        "hello")),
                                                                D.on(var_strings).execute(org.kie.kogito.examples.PF9.LambdaConsequenceF9EFB357CF6EB2205514EBE11E588FA1.INSTANCE));
        return rule;
    }
}
